@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -45,17 +43,17 @@ ExampleWindow::ExampleWindow(int which)
 
       // Create a PackBox - homogeneous = false, spacing = 0,
       // options = Gtk::PACK_SHRINK, padding = 0
-      pPackBox1 = Gtk::manage(new PackBox(false, 0, Gtk::PACK_SHRINK));
+      pPackBox1 = Gtk::make_managed<PackBox>(false, 0, Gtk::PACK_SHRINK);
       m_box1.pack_start(*pPackBox1, Gtk::PACK_SHRINK);
 
       // Create a PackBox - homogeneous = false, spacing = 0,
       // options = Gtk::PACK_EXPAND_PADDING, padding = 0
-      pPackBox2 = Gtk::manage(new PackBox(false, 0, Gtk::PACK_EXPAND_PADDING));
+      pPackBox2 = Gtk::make_managed<PackBox>(false, 0, Gtk::PACK_EXPAND_PADDING);
       m_box1.pack_start(*pPackBox2, Gtk::PACK_SHRINK);
 
       // Create a PackBox - homogeneous = false, spacing = 0,
       // options = Gtk::PACK_EXPAND_WIDGET, padding = 0
-      pPackBox3 = Gtk::manage(new PackBox(false, 0, Gtk::PACK_EXPAND_WIDGET));
+      pPackBox3 = Gtk::make_managed<PackBox>(false, 0, Gtk::PACK_EXPAND_WIDGET);
       m_box1.pack_start(*pPackBox3, Gtk::PACK_SHRINK);
 
       // pack the separator into the vbox.  Remember each of these
@@ -70,11 +68,11 @@ ExampleWindow::ExampleWindow(int which)
       m_box1.pack_start(m_Label2, Gtk::PACK_SHRINK);
 
       // Args are: homogeneous, spacing, options, padding
-      pPackBox4 = Gtk::manage(new PackBox(true, 0, Gtk::PACK_EXPAND_PADDING));
+      pPackBox4 = Gtk::make_managed<PackBox>(true, 0, Gtk::PACK_EXPAND_PADDING);
       m_box1.pack_start(*pPackBox4, Gtk::PACK_SHRINK);
 
       // Args are: homogeneous, spacing, options, padding
-      pPackBox5 = Gtk::manage(new PackBox(true, 0, Gtk::PACK_EXPAND_WIDGET));
+      pPackBox5 = Gtk::make_managed<PackBox>(true, 0, Gtk::PACK_EXPAND_WIDGET);
       m_box1.pack_start(*pPackBox5, Gtk::PACK_SHRINK);
 
       m_box1.pack_start(m_separator2, Gtk::PACK_SHRINK, 5);
@@ -90,10 +88,10 @@ ExampleWindow::ExampleWindow(int which)
       m_Label1.set_valign(Gtk::ALIGN_START);
       m_box1.pack_start(m_Label1, Gtk::PACK_SHRINK);
 
-      pPackBox1 = Gtk::manage(new PackBox(false, 10, Gtk::PACK_EXPAND_PADDING));
+      pPackBox1 = Gtk::make_managed<PackBox>(false, 10, Gtk::PACK_EXPAND_PADDING);
       m_box1.pack_start(*pPackBox1, Gtk::PACK_SHRINK);
 
-      pPackBox2 = Gtk::manage(new PackBox(false, 10, Gtk::PACK_EXPAND_WIDGET));
+      pPackBox2 = Gtk::make_managed<PackBox>(false, 10, Gtk::PACK_EXPAND_WIDGET);
       m_box1.pack_start(*pPackBox2, Gtk::PACK_SHRINK);
 
       m_box1.pack_start(m_separator1, Gtk::PACK_SHRINK, 5);
@@ -103,10 +101,10 @@ ExampleWindow::ExampleWindow(int which)
       m_Label2.set_valign(Gtk::ALIGN_START);
       m_box1.pack_start(m_Label2, Gtk::PACK_SHRINK);
 
-      pPackBox3 = Gtk::manage(new PackBox(false, 0, Gtk::PACK_SHRINK, 10));
+      pPackBox3 = Gtk::make_managed<PackBox>(false, 0, Gtk::PACK_SHRINK, 10);
       m_box1.pack_start(*pPackBox3, Gtk::PACK_SHRINK);
 
-      pPackBox4 = Gtk::manage(new PackBox(false, 0, Gtk::PACK_EXPAND_WIDGET, 10));
+      pPackBox4 = Gtk::make_managed<PackBox>(false, 0, Gtk::PACK_EXPAND_WIDGET, 10);
       m_box1.pack_start(*pPackBox4, Gtk::PACK_SHRINK);
 
       m_box1.pack_start(m_separator2, Gtk::PACK_SHRINK, 5);
@@ -118,7 +116,7 @@ ExampleWindow::ExampleWindow(int which)
     {
       // This demonstrates the ability to use Gtk::Box::pack_end() to
       // right justify widgets.  First, we create a new box as before.
-      pPackBox1 = Gtk::manage(new PackBox(false, 0, Gtk::PACK_SHRINK));
+      pPackBox1 = Gtk::make_managed<PackBox>(false, 0, Gtk::PACK_SHRINK);
 
       // create the label that will be put at the end.
       m_Label1.set_text("end");
@@ -173,4 +171,3 @@ void ExampleWindow::on_button_quit_clicked()
 {
   hide();
 }
-
