@@ -1,5 +1,3 @@
-//$Id: main.cc 824 2006-02-22 21:46:32Z murrayc $ -*- c++ -*-
-
 /* libglademm example Copyright (C) 2003 libglademm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,12 +16,32 @@
 
 #include "deriveddialog.h"
 #include <iostream>
+#include <cstring>
 
 int main (int argc, char **argv)
 {
-  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
+  bool show_icon = false;
+  bool is_glad = true;
+  int argc1 = argc;
+  if (argc > 1)
+  {
+    if (std::strcmp(argv[1], "--glad") == 0)
+    {
+      show_icon = true;
+      is_glad = true;
+      argc1 = 1; // Don't give the command line arguments to Gtk::Application.
+    }
+    else if (std::strcmp(argv[1], "--sad") == 0)
+    {
+      show_icon = true;
+      is_glad = false;
+      argc1 = 1; // Don't give the command line arguments to Gtk::Application.
+    }
+  }
 
-  //Load the Glade file and instiate its widgets:
+  auto app = Gtk::Application::create(argc1, argv, "org.gtkmm.example");
+
+  //Load the Glade file and instantiate its widgets:
   auto refBuilder = Gtk::Builder::create();
   try
   {
@@ -45,9 +63,13 @@ int main (int argc, char **argv)
     return 1;
   }
 
-  //Get the GtkBuilder-instantiated dialog::
+  //Get the GtkBuilder-instantiated dialog:
   DerivedDialog* pDialog = nullptr;
-  refBuilder->get_widget_derived("DialogDerived", pDialog);
+  if (show_icon)
+    // This call to get_widget_derived() requires gtkmm 3.19.7 or higher.
+    refBuilder->get_widget_derived("DialogDerived", pDialog, is_glad);
+  else
+    refBuilder->get_widget_derived("DialogDerived", pDialog);
   if(pDialog)
   {
     //Start:
