@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -34,25 +32,21 @@ ExampleWindow::ExampleWindow()
   m_VBox.set_border_width(10);
   m_Frame_Horizontal.add(m_VBox);
 
-  m_VBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(true, "Spread (spacing 40)", 40,
-                  Gtk::BUTTONBOX_SPREAD)),
-          Gtk::PACK_EXPAND_WIDGET);
+  m_VBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (true, "Spread (spacing 40)", 40, Gtk::BUTTONBOX_SPREAD),
+    Gtk::PACK_EXPAND_WIDGET);
 
-  m_VBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(true, "Edge (spacing 30)", 30,
-                  Gtk::BUTTONBOX_EDGE)),
-          Gtk::PACK_EXPAND_WIDGET, 5);
+  m_VBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (true, "Edge (spacing 30)", 30, Gtk::BUTTONBOX_EDGE),
+    Gtk::PACK_EXPAND_WIDGET, 5);
 
-  m_VBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(true, "Start (spacing 20)", 20,
-                  Gtk::BUTTONBOX_START)),
-          Gtk::PACK_EXPAND_WIDGET, 5);
+  m_VBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (true, "Start (spacing 20)", 20, Gtk::BUTTONBOX_START),
+    Gtk::PACK_EXPAND_WIDGET, 5);
 
-  m_VBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(true, "end (spacing 10)", 10,
-                  Gtk::BUTTONBOX_END)),
-          Gtk::PACK_EXPAND_WIDGET, 5);
+  m_VBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (true, "End (spacing 10)", 10, Gtk::BUTTONBOX_END),
+    Gtk::PACK_EXPAND_WIDGET, 5);
 
 
   //The vertical ButtonBoxes:
@@ -61,24 +55,21 @@ ExampleWindow::ExampleWindow()
   m_HBox.set_border_width(10);
   m_Frame_Vertical.add(m_HBox);
 
-  m_HBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(false, "Spread (spacing 5)", 5,
-                  Gtk::BUTTONBOX_SPREAD)),
-          Gtk::PACK_EXPAND_WIDGET);
+  m_HBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (false, "Spread (spacing 5)", 5, Gtk::BUTTONBOX_SPREAD),
+    Gtk::PACK_EXPAND_WIDGET);
 
-  m_HBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(false, "Edge (spacing 30)", 30,
-                  Gtk::BUTTONBOX_EDGE)),
-          Gtk::PACK_EXPAND_WIDGET, 5);
+  m_HBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (false, "Edge (spacing 30)", 30, Gtk::BUTTONBOX_EDGE),
+    Gtk::PACK_EXPAND_WIDGET, 5);
 
-  m_HBox.pack_start(*Gtk::manage(
-              new ExampleButtonBox(false, "Start (spacing 20)", 20,
-                  Gtk::BUTTONBOX_START)),
-          Gtk::PACK_EXPAND_WIDGET, 5);
+  m_HBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (false, "Start (spacing 20)", 20, Gtk::BUTTONBOX_START),
+    Gtk::PACK_EXPAND_WIDGET, 5);
 
-  m_HBox.pack_start(*Gtk::manage(new ExampleButtonBox(false, "End (spacing 10)",
-                  10, Gtk::BUTTONBOX_END)),
-          Gtk::PACK_EXPAND_WIDGET, 5);
+  m_HBox.pack_start(*Gtk::make_managed<ExampleButtonBox>
+    (false, "End (spacing 10)", 10, Gtk::BUTTONBOX_END),
+    Gtk::PACK_EXPAND_WIDGET, 5);
 
   show_all_children();
 }
