@@ -30,17 +30,17 @@ public:
 protected:
 
   //Overrides:
-  virtual Gtk::SizeRequestMode get_request_mode_vfunc() const;
-  virtual void get_preferred_width_vfunc(int& minimum_width, int& natural_width) const;
-  virtual void get_preferred_height_for_width_vfunc(int width, int& minimum_height, int& natural_height) const;
-  virtual void get_preferred_height_vfunc(int& minimum_height, int& natural_height) const;
-  virtual void get_preferred_width_for_height_vfunc(int height, int& minimum_width, int& natural_width) const;
-  virtual void on_size_allocate(Gtk::Allocation& allocation);
-  virtual void on_map();
-  virtual void on_unmap();
-  virtual void on_realize();
-  virtual void on_unrealize();
-  virtual bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr);
+  Gtk::SizeRequestMode get_request_mode_vfunc() const override;
+  void get_preferred_width_vfunc(int& minimum_width, int& natural_width) const override;
+  void get_preferred_height_for_width_vfunc(int width, int& minimum_height, int& natural_height) const  override;
+  void get_preferred_height_vfunc(int& minimum_height, int& natural_height) const override;
+  void get_preferred_width_for_height_vfunc(int height, int& minimum_width, int& natural_width) const override;
+  void on_size_allocate(Gtk::Allocation& allocation) override;
+  void on_map() override;
+  void on_unmap() override;
+  void on_realize() override;
+  void on_unrealize() override;
+  bool on_draw(const Cairo::RefPtr<Cairo::Context>& cr) override;
 
   //Signal handler:
   void on_parsing_error(const Glib::RefPtr<const Gtk::CssSection>& section, const Glib::Error& error);
