@@ -19,7 +19,7 @@
 
 int main(int argc, char *argv[])
 {
-  Glib::RefPtr<Gtk::Application> app = Gtk::Application::create(argc, argv, "org.gtkmm.example.flowbox");
+  auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example.flowbox");
 
   ExampleWindow window;
 
