@@ -154,15 +154,15 @@ Gtk::Widget* PrintFormOperation::on_create_custom_widget()
   //Create a custom tab in the print dialog titled "Other"
   set_custom_tab_label("Other");
 
-  auto vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL));
+  auto vbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_VERTICAL);
   vbox->set_border_width(12);
 
-  auto hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 8));
+  auto hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL, 8);
   vbox->pack_start(*hbox, false, false);
   hbox->set_border_width(6);
   hbox->show();
 
-  auto label = Gtk::manage(new Gtk::Label("Choose a font: "));
+  auto label = Gtk::make_managed<Gtk::Label>("Choose a font: ");
   hbox->pack_start(*label, false, false);
   label->show();
 
