@@ -17,12 +17,12 @@
 #include "examplewindow.h"
 #include <gtkmm/application.h>
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
   auto app = Gtk::Application::create(argc, argv, "org.gtkmm.example");
 
-  ExampleWindow window;
+  ExampleWindow window(app);
 
-  //Shows the window and returns when it is closed.
+  // Shows the window and returns when it is closed.
   return app->run(window);
 }
