@@ -1,5 +1,3 @@
-//$Id: examplewindow.h 705 2006-07-19 02:55:32Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -44,7 +42,7 @@ protected:
   Gtk::CheckButton m_CheckButton_Text, m_CheckButton_Activity, m_CheckButton_Inverted;
   Gtk::Button m_Button_Close;
 
-  int m_connection_id_timeout;
+  sigc::connection m_connection_timeout;
   bool m_bActivityMode;
 };
 
