@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 870 2007-07-13 19:08:46Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -48,15 +46,15 @@ ExampleWindow::ExampleWindow()
 
     m_Toolbar.set_toolbar_style(Gtk::TOOLBAR_BOTH);
 
-    auto item = Gtk::manage(new Gtk::ToolButton("Click me"));
+    auto item = Gtk::make_managed<Gtk::ToolButton>("Click me");
     //item.set_tooltips(*tooltips, "Toolbar item");
     m_Toolbar.append(*item);
     item->signal_clicked().connect( sigc::mem_fun(*this,
                 &ExampleWindow::on_toolbar_item) );
 
-    m_Toolbar.append( *(Gtk::manage(new Gtk::SeparatorToolItem)) );
+    m_Toolbar.append(*Gtk::make_managed<Gtk::SeparatorToolItem>());
 
-    item = Gtk::manage(new Gtk::ToolButton("_Save"));
+    item = Gtk::make_managed<Gtk::ToolButton>("_Save");
     item->set_use_underline();
     item->set_icon_name("document-save");
     item->set_homogeneous(false);
@@ -64,19 +62,16 @@ ExampleWindow::ExampleWindow()
     item->signal_clicked().connect( sigc::mem_fun(*this,
                 &ExampleWindow::on_toolbar_item) );
 
-    item = Gtk::manage(new Gtk::ToggleToolButton("Toggle me"));
+    item = Gtk::make_managed<Gtk::ToggleToolButton>("Toggle me");
     //item.set_tooltips(*tooltips, "toggle duh");
     m_Toolbar.append(*item);
     item->signal_clicked().connect( sigc::mem_fun(*this,
                 &ExampleWindow::on_toolbar_item) );
 
     Gtk::RadioButtonGroup group;
-    m_Toolbar.append( *Gtk::manage(
-                new Gtk::RadioToolButton(group, "Radio 1")) );
-    m_Toolbar.append( *Gtk::manage(
-                new Gtk::RadioToolButton(group, "Radio 2")) );
-    m_Toolbar.append( *Gtk::manage(
-                new Gtk::RadioToolButton(group, "Radio 3")) );
+    m_Toolbar.append(*Gtk::make_managed<Gtk::RadioToolButton>(group, "Radio 1"));
+    m_Toolbar.append(*Gtk::make_managed<Gtk::RadioToolButton>(group, "Radio 2"));
+    m_Toolbar.append(*Gtk::make_managed<Gtk::RadioToolButton>(group, "Radio 3"));
   }
 
   show_all_children();
