@@ -1,5 +1,3 @@
-//$Id: examplewindow.cc 836 2007-05-09 03:02:38Z jjongsma $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -94,10 +92,8 @@ ExampleWindow::ExampleWindow()
   m_TreeView.append_column("Name", m_Columns.m_col_name);
 
   //Create a Combo CellRenderer, instead of the default Text CellRenderer:
-  auto pColumn = Gtk::manage(
-          new Gtk::TreeView::Column("Item Chosen") );
-  auto pRenderer = Gtk::manage(
-          new Gtk::CellRendererCombo);
+  auto pColumn = Gtk::make_managed<Gtk::TreeView::Column>("Item Chosen");
+  auto pRenderer = Gtk::make_managed<Gtk::CellRendererCombo>();
   pColumn->pack_start(*pRenderer);
   m_TreeView.append_column(*pColumn);
 
