@@ -56,23 +56,23 @@ AppWindow::AppWindow()
   set_border_width (10);
 
   /* Create a grid to hold the arrows/buttons */
-  grid = Gtk::manage (new Gtk::Grid ());
+  grid = Gtk::make_managed<Gtk::Grid>();
   grid->set_row_homogeneous(true);
   grid->set_column_homogeneous(true);
   grid->set_border_width (2);
 
   /* Pack and show all our widgets */
-  button = Gtk::manage (new ArrowButton (Gtk::ARROW_UP));
-  grid->attach (*button, 1, 0, 1, 1);
+  button = Gtk::make_managed<ArrowButton>(Gtk::ARROW_UP);
+  grid->attach (*button, 1, 0);
 
-  button = Gtk::manage (new ArrowButton (Gtk::ARROW_LEFT));
-  grid->attach (*button, 0, 1, 1, 1);
+  button = Gtk::make_managed<ArrowButton>(Gtk::ARROW_LEFT);
+  grid->attach (*button, 0, 1);
 
-  button = Gtk::manage (new ArrowButton (Gtk::ARROW_RIGHT));
-  grid->attach (*button, 2, 1, 1, 1);
+  button = Gtk::make_managed<ArrowButton>(Gtk::ARROW_RIGHT);
+  grid->attach (*button, 2, 1);
 
-  button = Gtk::manage (new ArrowButton (Gtk::ARROW_DOWN));
-  grid->attach (*button, 1, 2, 1, 1);
+  button = Gtk::make_managed<ArrowButton>(Gtk::ARROW_DOWN);
+  grid->attach (*button, 1, 2);
 
   grid->set_row_spacing(5);
   grid->set_column_spacing(5);
