@@ -177,22 +177,22 @@ CalendarExample::CalendarExample()
 
   set_resizable(false);
 
-  auto vbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, DEF_PAD));
+  auto vbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_VERTICAL, DEF_PAD);
   add(*vbox);
 
   /*
    * The top part of the CalendarExample, flags and fontsel.
    */
 
-  auto hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, DEF_PAD));
+  auto hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL, DEF_PAD);
   vbox->pack_start(*hbox, Gtk::PACK_EXPAND_WIDGET, DEF_PAD);
-  auto hbbox = Gtk::manage(new Gtk::ButtonBox());
+  auto hbbox = Gtk::make_managed<Gtk::ButtonBox>();
   hbox->pack_start(*hbbox, Gtk::PACK_SHRINK, DEF_PAD);
   hbbox->set_layout(Gtk::BUTTONBOX_SPREAD);
   hbbox->set_spacing(5);
 
   /* Calendar widget */
-  auto frame = Gtk::manage(new Gtk::Frame("Calendar"));
+  auto frame = Gtk::make_managed<Gtk::Frame>("Calendar");
   hbbox->pack_start(*frame, Gtk::PACK_EXPAND_WIDGET, DEF_PAD);
   calendar_ = new Gtk::Calendar();
   set_flags();
@@ -202,17 +202,17 @@ CalendarExample::CalendarExample()
   calendar_->signal_day_selected().connect(sigc::mem_fun(*this, &CalendarExample::day_selected));
   calendar_->signal_day_selected_double_click().connect(sigc::mem_fun(*this, &CalendarExample::day_selected_double_click));
 
-  auto separator = Gtk::manage(new Gtk::Separator(Gtk::ORIENTATION_VERTICAL));
+  auto separator = Gtk::make_managed<Gtk::Separator>(Gtk::ORIENTATION_VERTICAL);
   hbox->pack_start (*separator, Gtk::PACK_SHRINK);
 
-  auto vbox2 = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, DEF_PAD));
+  auto vbox2 = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_VERTICAL, DEF_PAD);
   hbox->pack_start(*vbox2, Gtk::PACK_SHRINK, DEF_PAD);
 
   /* Build the Right frame with the flags in */
 
-  auto frameFlags = Gtk::manage(new Gtk::Frame("Flags"));
+  auto frameFlags = Gtk::make_managed<Gtk::Frame>("Flags");
   vbox2->pack_start(*frameFlags, Gtk::PACK_EXPAND_WIDGET, DEF_PAD);
-  auto vbox3 = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, DEF_PAD_SMALL));
+  auto vbox3 = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_VERTICAL, DEF_PAD_SMALL);
   frameFlags->add(*vbox3);
 
   struct {
@@ -235,7 +235,7 @@ CalendarExample::CalendarExample()
   }
 
   /* Build the right font-button */
-  font_button_ = Gtk::manage(new Gtk::FontButton());
+  font_button_ = Gtk::make_managed<Gtk::FontButton>();
   font_button_->signal_font_set().connect(sigc::mem_fun(*this, &CalendarExample::on_font_button_font_set));
   vbox2->pack_start(*font_button_, Gtk::PACK_SHRINK);
 
@@ -253,37 +253,37 @@ CalendarExample::CalendarExample()
   /*
    *  Build the Signal-event part.
    */
-  frame = Gtk::manage(new Gtk::Frame("Signal events"));
+  frame = Gtk::make_managed<Gtk::Frame>("Signal events");
   vbox->pack_start(*frame, Gtk::PACK_EXPAND_WIDGET, DEF_PAD);
-  vbox2 = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_VERTICAL, DEF_PAD_SMALL));
+  vbox2 = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_VERTICAL, DEF_PAD_SMALL);
   frame->add(*vbox2);
 
-  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 5));
+  hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL, 5);
   vbox2->pack_start (*hbox, Gtk::PACK_SHRINK);
-  auto label = Gtk::manage(new Gtk::Label("Day selected:"));
+  auto label = Gtk::make_managed<Gtk::Label>("Day selected:");
   hbox->pack_start (*label, Gtk::PACK_SHRINK);
   label_selected_ = new Gtk::Label("");
   hbox->pack_start (*label_selected_, Gtk::PACK_SHRINK);
 
-  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 5));
+  hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL, 5);
   vbox2->pack_start (*hbox, Gtk::PACK_SHRINK);
-  label = Gtk::manage(new Gtk::Label("Day selected double click:"));
+  label = Gtk::make_managed<Gtk::Label>("Day selected double click:");
   hbox->pack_start (*label, Gtk::PACK_SHRINK);
   label_selected_double_click_ = new Gtk::Label("");
   hbox->pack_start (*label_selected_double_click_, Gtk::PACK_SHRINK);
 
-  hbox = Gtk::manage(new Gtk::Box(Gtk::ORIENTATION_HORIZONTAL, 5));
+  hbox = Gtk::make_managed<Gtk::Box>(Gtk::ORIENTATION_HORIZONTAL, 5);
   vbox2->pack_start (*hbox, Gtk::PACK_SHRINK);
-  label = Gtk::manage(new Gtk::Label("Month change:"));
+  label = Gtk::make_managed<Gtk::Label>("Month change:");
   hbox->pack_start (*label, Gtk::PACK_SHRINK);
   label_month_ = new Gtk::Label("");
   hbox->pack_start(*label_month_, Gtk::PACK_SHRINK);
 
-  auto bbox = Gtk::manage(new Gtk::ButtonBox());
+  auto bbox = Gtk::make_managed<Gtk::ButtonBox>();
   vbox->pack_start(*bbox, Gtk::PACK_SHRINK);
   bbox->set_layout(Gtk::BUTTONBOX_END);
 
-  auto button = Gtk::manage(new Gtk::Button("Close"));
+  auto button = Gtk::make_managed<Gtk::Button>("Close");
   button->signal_clicked().connect(
     sigc::mem_fun(*this, &CalendarExample::on_button_close));
   bbox->add(*button);
