@@ -1,5 +1,3 @@
-//$Id: dndwindow.cc 177 2004-03-28 18:58:09Z murrayc $ -*- c++ -*-
-
 /* gtkmm example Copyright (C) 2002 gtkmm development team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -235,7 +233,7 @@ void DnDWindow::create_popup()
   m_PopupWindow.set_position(Gtk::WIN_POS_MOUSE);
 
   //Create Grid and fill it:
-  auto pGrid = Gtk::manage(new Gtk::Grid());
+  auto pGrid = Gtk::make_managed<Gtk::Grid>();
 
   for(int i = 0; i < 3; i++)
   {
@@ -243,8 +241,8 @@ void DnDWindow::create_popup()
     {
       char buffer[128];
       g_snprintf(buffer, sizeof(buffer), "%d,%d", i, j);
-      auto pButton = Gtk::manage(new Gtk::Button(buffer));
-      pGrid->attach(*pButton, i, j, 1, 1);
+      auto pButton = Gtk::make_managed<Gtk::Button>(buffer);
+      pGrid->attach(*pButton, i, j);
 
       pButton->drag_dest_set(m_listTargetsNoRoot, Gtk::DEST_DEFAULT_ALL, Gdk::DragAction(GDK_ACTION_COPY | GDK_ACTION_MOVE));
       pButton->signal_drag_motion().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_button_drag_motion) );                      pButton->signal_drag_leave().connect( sigc::mem_fun(*this, &DnDWindow::on_popup_button_drag_leave) );
